import os

with open('README.md', 'w') as mkdn:
	mkdn.write("Screenshots\n===\n")
	for f in [f for f in os.listdir('.') if os.path.isfile(f)]:
		mkdn.write("`%s`\n\n" % f)
		mkdn.write("![image](%s)\n\n" % f)




#!/usr/bin/env python

# This script converts xrdb (X11) color scheme format to terminator color
# scheme format
#
# Usage:
# xrdb2terminator.py path/to/xrdb/files -d /terminator/schemes/output
#
# Author: Xabier Larrakoetxea

import os
import sys
import re
import argparse

if __name__ == "__main__":

    parser = argparse.ArgumentParser(
        description='Translate X color schemes to termiantor format')
    parser.add_argument('xrdb_path', type=str, help='path to xrdb files')
    parser.add_argument('-d', '--destiny', type=str, dest='output_path',
                        help='path where terminator config files will be' +
                        ' created, if not provided then will be printed')

    args = parser.parse_args()


    # The regexes to match the colors
    color_regex = re.compile("#define +Ansi_(\d+)_Color +(#[A-Fa-f0-9]{6})")
    bg_regex = re.compile("#define +Background_Color +(#[A-Fa-f0-9]{6})")
    fg_regex = re.compile("#define +Foreground_Color +(#[A-Fa-f0-9]{6})")
    cursor_regex = re.compile("#define +Cursor_Color +(#[A-Fa-f0-9]{6})")

    # File regex
    xrdb_regex = re.compile("(.+)\.[xX][rR][dD][bB]")

    for i in filter(lambda x: xrdb_regex.match(x), os.listdir(args.xrdb_path)):

        # per file
        with open(os.path.join(args.xrdb_path, i)) as f:
            lines = f.readlines()

        # Search special colors
        color_file = "\n".join(lines)

        bg_color = bg_regex.search(color_file).group(1)
        fg_color = fg_regex.search(color_file).group(1)
        cursor_color = cursor_regex.search(color_file).group(1)

        # Search palette
        colors = sorted(filter(lambda x: color_regex.match(x), lines),
                        key=lambda x: int(color_regex.match(x).group(1)))

        # Create the color string
        colors = ":".join(map(lambda x: color_regex.match(x).group(2), colors))

        scheme = """
[[{name}]]
    palette = "{pl}"
    background_color = "{bg}"
    cursor_color = "{cr}"
    foreground_color = "{fg}"
    background_image = None
"""

        output = scheme.format(name=xrdb_regex.match(i).group(1),
                               pl=colors,
                               bg=bg_color,
                               cr=cursor_color,
                               fg=fg_color)

        if not args.output_path:
            print(output)
        else:
            dest = os.path.join(args.output_path, xrdb_regex.match(i).group(1))
            with open('{0}.config'.format(dest), 'w+') as f:
                f.write(output)



#!/usr/bin/env python
from collections import deque
from threading import Thread
from time import sleep
import argparse
import os
import random
import readline
import subprocess
import sys

import getchs


class Scheme(object):
    """
    An iTerm2 color scheme.
    """
    def __init__(self, path):
        self.path = path

    @property
    def name(self):
        return os.path.basename(self.path).split('.')[0]

    def __repr__(self):
        return self.name


class ColorSchemeSelector(object):
    """
    An interactive iTerm2 color scheme selector.
    """
    # Animation control keys
    PAUSE = {' '}
    NEXT = {'j', 'n', getchs.RIGHT, getchs.DOWN}
    PREV = {'k', 'p', getchs.LEFT, getchs.UP}
    QUIT = {'q', '\r', getchs.CTRL_C}

    def __init__(self, quiet=True):
        self.quiet = quiet
        self.repo_dir = os.path.join(os.path.dirname(__file__),
                                     'iTerm2-Color-Schemes')
        schemes_dir = self.repo_dir + '/schemes'
        self.schemes = deque(
            Scheme(os.path.join(schemes_dir, scheme_file))
            for scheme_file in os.listdir(schemes_dir)
            if scheme_file.endswith('.itermcolors')
        )
        self.name_to_scheme = {s.name: s for s in self.schemes}
        self.scheme_names = [s.name for s in self.schemes]
        self.blank = ' ' * max(len(s.name) for s in self.schemes)

        self.animation_control = Thread(target=self.control)
        self.paused = False
        self.quitting = False

    @property
    def scheme(self):
        return self.schemes[0]

    def next(self):
        self.schemes.rotate(-1)

    def prev(self):
        self.schemes.rotate(+1)

    def goto(self, scheme):
        self.schemes.rotate(-list(self.schemes).index(scheme))

    def shuffle(self):
        random.shuffle(self.schemes)
        self.scheme_names = [s.name for s in self.schemes]

    def apply(self):
        """
        Apply current scheme to current iTerm2 session.
        """
        subprocess.check_call([
            self.repo_dir + '/tools/preview.rb',
            self.scheme.path,
        ])

    def say(self, msg):
        if not self.quiet:
            if len(msg) > len(self.blank):
                self.blank = ' ' * len(msg)
            sys.stdout.write(msg)
            sys.stdout.flush()

    def tell(self):
        sys.stdout.write('\r%s\r%s' % (self.blank, self.scheme))
        sys.stdout.flush()

    def animate(self, speed, shuffle):
        """
        Cycle through schemes automatically.

        Keys can be used to pause, and go forwards/backwards.
        """
        if shuffle:
            self.shuffle()
        self.animation_control.start()
        self.prev()
        while True:
            if self.quitting:
                self.quit()
            elif self.paused:
                sleep(0.1)
            else:
                self.next()
                self.apply()
                self.tell()
                sleep(1.0 / speed)

    def control(self):
        while True:
            chars = getchs.getchs()
            if chars in self.PAUSE:
                self.paused = not self.paused
            elif chars in self.NEXT:
                self.next()
                self.apply()
                self.tell()
            elif chars in self.PREV:
                self.prev()
                self.apply()
                self.tell()
            elif chars in self.QUIT:
                self.quitting = True
                break

    def quit(self):
        self.animation_control.join()
        print
        sys.exit(0)

    def select(self):
        """
        Select a color theme interactively.
        """
        readline.set_completer(self.complete)
        readline.set_completer_delims('')
        readline.parse_and_bind('tab: complete')
        readline.parse_and_bind('set completion-ignore-case on')
        readline.parse_and_bind('set completion-query-items -1')
        readline.parse_and_bind('set show-all-if-ambiguous on')
        readline.parse_and_bind('"\e[C": menu-complete')
        readline.parse_and_bind('"\e[D": menu-complete-backward')

        while True:
            try:
                self.goto(self.name_to_scheme[raw_input()])
            except KeyboardInterrupt:
                print
                sys.exit(0)
            except KeyError:
                sys.exit(1)
            else:
                self.apply()

    def complete(self, text, state):
        """
        Return state'th completion for current input.

        This is the standard readline completion function.
        https://docs.python.org/2/library/readline.html

        text: the current input
        state: an integer specifying which of the matches for the current input
               should be returned
        """
        if state == 0:
            # First call for current input; compute and cache completions
            if text:
                self.current_matches = self.get_matches(text)

                if len(self.current_matches) == 1:
                    # Unique match; apply scheme and return the completion
                    [completion] = self.current_matches
                    self.goto(self.name_to_scheme[completion])
                    self.apply()
                    return completion
            else:
                self.current_matches = self.scheme_names
        try:
            completion = self.current_matches[state]
        except IndexError:
            completion = None

        return completion

    def get_matches(self, text):
        """
        Return matches for current readline input.
        """
        if text.endswith('$'):
            text = text[:-1]
            if text in self.name_to_scheme:
                return [text]
            else:
                return []
        else:
            return [
                name
                for name in self.scheme_names
                if text.lower() in name.lower()
            ]


DEFAULT_HELP_MESSAGE = "Use left/right or j/k or n/p to select color schemes"


def parse_arguments():
    selector = ColorSchemeSelector()
    arg_parser = argparse.ArgumentParser(
        description=(
            "Color theme selector for iTerm2.\n\n%s"
            ", or supply one of the arguments below.") % DEFAULT_HELP_MESSAGE,
        epilog=(
            "The color schemes are from "
            "https://github.com/mbadolato/iTerm2-Color-Schemes, which is "
            "included as a git submodule in this project. All credit for the "
            "schemes goes to the original scheme authors and to the "
            "iTerm2-Color-Schemes project. To add a new scheme, please first "
            "create a pull request against iTerm2-Color-Schemes to add your "
            "scheme, and then open a pull request or issue against "
            "https://github.com/dandavison/iterminator to update the "
            "submodule."),
        formatter_class=argparse.RawTextHelpFormatter,
    )

    arg_parser.add_argument(
        '-a', '--animation-speed',
        nargs='?',
        metavar='speed',
        type=float,
        const=1.0,
        help=("Cycle through color schemes automatically.\n"
              "Optional value is animation speed (schemes/second)\n"
              "Key bindings:\n"
              "space             - pause/unpause\n"
              "right arrow, j, n - next scheme\n"
              "left arrow, k, p  - previous scheme\n"
              "return            - quit\n\n"),
    )

    arg_parser.add_argument(
        '-i', '--interactive',
        action='store_true',
        help=("Select color scheme with tab-completion.\n"
              "Key bindings:\n"
              "tab         - complete\n"
              "right arrow - next completion\n"
              "left arrow  - previous completion\n"
              "return      - select\n"
              "Plus the usual emacs-based readline defaults such as\n"
              "ctrl a      - beginning of line\n"
              "ctrl k      - kill to end of line\n\n"),
    )

    arg_parser.add_argument(
        '-l', '--list',
        action='store_true',
        help="List available color schemes\n\n",
    )

    arg_parser.add_argument(
        '-q', '--quiet',
        action='store_true',
        help="Don't display initial key bindings help message\n\n",
    )

    arg_parser.add_argument(
        '-r', '--random',
        action='store_true',
        help="Select a random color scheme\n\n"
    )

    arg_parser.add_argument(
        '-v', '--version',
        action='store_true',
        help="Show version\n\n"
    )

    arg_parser.add_argument(
        '-s', '--scheme',
        help="Available choices are\n%s" % ' | '.join(selector.scheme_names),
    )

    return arg_parser.parse_args()


def main():
    if os.getenv('TMUX'):
        error(
            "Please detach from your tmux session before running this command."
        )

    args = parse_arguments()
    selector = ColorSchemeSelector(quiet=args.quiet)

    if args.animation_speed:

        try:
            selector.animate(args.animation_speed, args.random)
        except KeyboardInterrupt:
            print
            sys.exit(0)

    if args.interactive:

        selector.say('Tab to complete color scheme names\n')
        selector.select()

    elif args.list:

        for scheme in selector.schemes:
            print scheme

    elif args.random:

        selector.shuffle()
        selector.apply()
        print selector.scheme

    elif args.scheme:

        names = selector.get_matches(args.scheme)
        if len(names) == 0:
            error("No matches")
        elif len(names) == 1:
            [name] = names
            scheme = selector.name_to_scheme[name]
            selector.goto(scheme)
            selector.apply()
            print selector.scheme
        elif len(names) > 1:
            error("Multiple matches: %s" % ', '.join(names))

    elif args.version:
        with open(os.path.join(os.path.dirname(__file__),
                               'version.txt')) as fp:
            print fp.read().strip()

    else:

        try:
            selector.say(DEFAULT_HELP_MESSAGE)
            selector.prev()
            selector.control()
        except KeyboardInterrupt:
            print
            sys.exit(0)


def error(msg):
    print >>sys.stderr, msg
    sys.exit(1)


if __name__ == '__main__':
    main()



from select import select
from sys import stdin
from time import sleep
import fcntl
import os
import termios
import tty


POLL_INTERVAL = 0.1

CTRL_C = '\x03'
LEFT = '\x1b[D'
RIGHT = '\x1b[C'
UP = '\x1b[A'
DOWN = '\x1b[B'


def setNonBlocking(fd):
    """
    Set the file description of the given file descriptor to non-blocking.

    Copied from twisted.internet.fdesc.setNonBlocking()
    https://github.com/twisted/twisted
    """
    flags = fcntl.fcntl(fd, fcntl.F_GETFL)
    flags = flags | os.O_NONBLOCK
    fcntl.fcntl(fd, fcntl.F_SETFL, flags)


def getchs():
    """
    Block until there are bytes to read on stdin and then return them all.

    Adapted from getch()
    https://github.com/joeyespo/py-getch.
    """
    fd = stdin.fileno()
    old = termios.tcgetattr(fd)
    setNonBlocking(fd)
    try:
        tty.setraw(fd)
        while not select([stdin], [], [], 0)[0]:
            sleep(POLL_INTERVAL)
        return stdin.read()
    finally:
        termios.tcsetattr(fd, termios.TCSADRAIN, old)


if __name__ == '__main__':
    while True:
        chars = getchs()
        if chars == CTRL_C:
            exit(0)
        else:
            print '%r' % chars



import os

from setuptools import find_packages
from setuptools import setup


setup(
    name='iterminator',
    version=(open(os.path.join(os.path.dirname(__file__),
                               'iterminator',
                               'version.txt'))
             .read().strip()),
    author='Dan Davison',
    author_email='dandavison7@gmail.com',
    description="Command-line color scheme selector for iTerm2",
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    entry_points={
        'console_scripts': [
            'iterminator = iterminator.iterminator:main',
        ],
    },
)



#!/usr/bin/env python
# coding: utf-8
#
# This script converts xrdb (X11) color scheme format to Konsole color
# scheme format
#
# Usage:
# xrdb2konsole.py path/to/xrdb/files -d /konsole/schemes/output
#
# Author: Stéphane Travostino
# Adapted from xrdb2terminator by Xabier Larrakoetxea

import os
import sys
import re
import argparse

# Takes #000A0B and returns (0, 10, 11)
def hex_to_rgb(color):
    return (int(color[1:3], 16), int(color[3:5], 16), int(color[5:7], 16))

def build_konsole_color(name, r, g, b):
    return "[%s]\nColor=%d,%d,%d\n\n" % (name, r, g, b)

if __name__ == "__main__":

    parser = argparse.ArgumentParser(
        description='Translate X color schemes to termiantor format')
    parser.add_argument('xrdb_path', type=str, help='path to xrdb files')
    parser.add_argument('-d', '--out-directory', type=str, dest='output_path',
                        help='path where terminator config files will be' +
                        ' created, if not provided then will be printed')

    args = parser.parse_args()


    # The regexes to match the colors
    color_regex = re.compile("#define +Ansi_(\d+)_Color +(#[A-Fa-f0-9]{6})")
    bg_regex = re.compile("#define +Background_Color +(#[A-Fa-f0-9]{6})")
    fg_regex = re.compile("#define +Foreground_Color +(#[A-Fa-f0-9]{6})")
    bold_regex = re.compile("#define +Bold_Color +(#[A-Fa-f0-9]{6})")
    cursor_regex = re.compile("#define +Cursor_Color +(#[A-Fa-f0-9]{6})")

    # File regex
    xrdb_regex = re.compile("(.+)\.[xX][rR][dD][bB]")

    for i in filter(lambda x: xrdb_regex.match(x), os.listdir(args.xrdb_path)):
        name = xrdb_regex.match(i).group(1)

        # Read XRDB file
        with open(os.path.join(args.xrdb_path, i)) as f:
            xrdb_data = f.read()

        # Open output file
        output = sys.stdout

        if args.output_path:
            dest = os.path.join(args.output_path, name)
            output = open('{0}.colorscheme'.format(dest), 'w+')
        else:
            output.write('\n%s:\n' % name)

        # Emit header
        output.write("[General]\nDescription=%s\nOpacity=1\nWallpaper=\n\n" % name)

        # Emit background color
        bg_color = hex_to_rgb(bg_regex.search(xrdb_data).group(1))
        output.write(build_konsole_color('Background', *bg_color))
        output.write(build_konsole_color('BackgroundIntense', *bg_color))

        # Emit foreground color
        fg_color = hex_to_rgb(fg_regex.search(xrdb_data).group(1))
        output.write(build_konsole_color('Foreground', *fg_color))

        # Emit bold color, if any
        match = bold_regex.search(xrdb_data)
        if match:
            bold_color = hex_to_rgb(match.group(1))
            output.write(build_konsole_color('ForegroundIntense', *bold_color))
        else:
            output.write(build_konsole_color('ForegroundIntense', *fg_color))

        # Emit other colors
        for match in color_regex.findall(xrdb_data):
            color_index = int(match[0])
            color_rgb = hex_to_rgb(match[1])

            color_name = 'Color%d' % color_index if color_index < 8 else 'Color%dIntense' % (color_index - 8)

            output.write(build_konsole_color(color_name, *color_rgb))

        if args.output_path:
            output.close()
